# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from django import forms


#from searchableselect.widgets import SearchableSelect

#from django.template.response import TemplateResponse
#from django.http import HttpResponse
#try:
#    from django.utils.encoding import force_text
#except ImportError:
#    from django.utils.encoding import force_unicode as force_text
#from import_export.forms import ConfirmImportForm



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models
from django.contrib.auth.models import User
#from colorfield.fields import ColorField
from django.core.validators import MinValueValidator
#from multiselectfield import MultiSelectField
from django.core.exceptions import ValidationError
from django.db.models.fields import BooleanField, TextField, CharField

import re
from datetime import datetime, timedelta
import pytz


from setuptools import setup, find_packages
from os import path
from io import open

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='django_tst_cms',  # Required
    version='1.5.0',  # Required
    description='CMS project',  # Optional
    include_package_data = True,
    long_description=long_description,  # Optional
    long_description_content_type='text/markdown',  # Optional (see note above)
    url='https://github.com/DianaHov/test-cms',  # Optional
    author='Diana Hovhannisyan',  # Optional
    author_email='d.hovhannisyan@gmail.com',  # Optional

    # Classifiers help users find your project by categorizing it.
    #
    # For a list of valid classifiers, see https://pypi.org/classifiers/
    classifiers=[  # Optional
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        # Pick your license as you wish
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
    ],
    keywords='cms django workflow',  # Optional
    packages=find_packages(),  # Required
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, <4',
    install_requires=['django_tst_cms','Django>1.8','Django<2',],  # Optional
)


import sys

from django.contrib.auth.management import _get_all_permissions
from django.contrib.auth.models import Permission
from django.contrib.contenttypes.models import ContentType
from django.core.management.base import BaseCommand
from django.apps import apps


class Command(BaseCommand):
    help = "Fix permissions for proxy models."

    def handle(self, *args, **options):
        for model in apps.get_models():
            opts = model._meta
            sys.stdout.write('{}-{}\n'.format(opts.app_label, opts.object_name.lower()))
            ctype, created = ContentType.objects.get_or_create(
                app_label=opts.app_label,
                model=opts.object_name.lower())

            for codename, name in _get_all_permissions(opts):
                sys.stdout.write('  --{}\n'.format(codename))
                p, created = Permission.objects.get_or_create(
                    codename=codename,
                    content_type=ctype,
                    defaults={'name': name})
                if created:
                    sys.stdout.write('Adding permission {}\n'.format(p))


from django.views.generic import TemplateView
#from home.forms import HomeForm
from django.http import HttpResponse, HttpResponseForbidden, HttpResponseBadRequest
from django.shortcuts import render, redirect

import json, pytz, requests

import ast

#from django.contrib.auth.models import User



def home(request):
    user = request.user
    args = {'user': user}
    return render(request, 'alerts/home.html', args)

